@@ -8,6 +8,7 @@ import re
 import warnings
 from collections import defaultdict
 from dataclasses import dataclass
+from textwrap import dedent
 from typing import Any, Dict, List, Optional, Tuple
 
 from omegaconf import Container, DictConfig, ListConfig, OmegaConf, open_dict
@@ -70,7 +71,7 @@ class ConfigLoaderImpl(ConfigLoader):
     def __init__(
         self,
         config_search_path: ConfigSearchPath,
-        default_strict: Optional[bool] = None,
+        default_strict: Optional[bool] = True,
     ) -> None:
         self.default_strict = default_strict
         self.all_config_checked: List[LoadTrace] = []
@@ -85,7 +86,9 @@ class ConfigLoaderImpl(ConfigLoader):
         config_group_overrides = []
         config_overrides = []
         for override in overrides:
-            if not self.repository.group_exists(override.key_or_group):
+            is_group = self.repository.group_exists(override.key_or_group)
+            is_dict = isinstance(override.value(), dict)
+            if is_dict or not is_group:
                 config_overrides.append(override)
             else:
                 config_group_overrides.append(override)
@@ -193,10 +196,13 @@ class ConfigLoaderImpl(ConfigLoader):
                         else:
                             example_override = f"key='{vals}'"
 
-                        msg = f"""Ambiguous value for argument '{x.input_line}'
-1. To use it as a list, use key=[value1,value2]
-2. To use it as string, quote the value: {example_override}
-3. To sweep over it, add --multirun to your command line"""
+                        msg = dedent(
+                            f"""\
+                            Ambiguous value for argument '{x.input_line}'
+                            1. To use it as a list, use key=[value1,value2]
+                            2. To use it as string, quote the value: {example_override}
+                            3. To sweep over it, add --multirun to your command line"""
+                        )
                         raise ConfigCompositionException(msg)
                     else:
                         raise ConfigCompositionException(
@@ -493,19 +499,21 @@ class ConfigLoaderImpl(ConfigLoader):
                             del node[key[last_dot + 1 :]]
 
                 elif override.is_add():
-                    if OmegaConf.select(cfg, key, throw_on_missing=False) is None:
+                    if OmegaConf.select(
+                        cfg, key, throw_on_missing=False
+                    ) is None or isinstance(value, (dict, list)):
                         with open_dict(cfg):
-                            OmegaConf.update(cfg, key, value)
+                            OmegaConf.update(cfg, key, value, merge=True)
                     else:
                         raise ConfigCompositionException(
                             f"Could not append to config. An item is already at '{override.key_or_group}'."
                         )
                 else:
                     try:
-                        OmegaConf.update(cfg, key, value)
+                        OmegaConf.update(cfg, key, value, merge=True)
                     except (ConfigAttributeError, ConfigKeyError) as ex:
                         raise ConfigCompositionException(
-                            f"Could not override '{override.key_or_group}'. No match in config."
+                            f"Could not override '{override.key_or_group}'."
                             f"\nTo append to your config use +{override.input_line}"
                         ) from ex
             except OmegaConfBaseException as ex:
