@@ -39,7 +39,15 @@ class TestBasicLauncherIntegration(IntegrationTestSuite):
 
 @pytest.mark.parametrize(
     "launcher_name, overrides",
-    [("basic", ["hydra/sweeper=basic", "hydra.sweeper.max_batch_size=2"])],
+    [
+        (
+            "basic",
+            [
+                "hydra/sweeper=basic",
+                "hydra.sweeper.max_batch_size=2",
+            ],
+        )
+    ],
 )
 class TestBasicSweeperWithBatching(BatchedSweeperTestSuite):
     ...
